==> haskell-rate-limit-1.4.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rate-limit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rate-limit
version:              1.4.3
visibility:           public
id:                   rate-limit-1.4.3-GgKPfmYk1rq2rp9ut0wxbG
key:                  rate-limit-1.4.3-GgKPfmYk1rq2rp9ut0wxbG
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/rate-limit
synopsis:             A basic library for rate-limiting IO actions.
description:
    In many cases, it is useful, necessary, or simply nice to limit how
    frequently you perform some action. For example, you may want to limit
    how often your program makes a request of some web site. This library
    is intended as a general-purpose mechanism for rate-limiting IO actions.

category:             Control
abi:                  7da58446bff9db7cb70fd01dae7027b2
exposed:              True
exposed-modules:      Control.RateLimit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rate-limit-1.4.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rate-limit-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rate-limit
hs-libraries:         HSrate-limit-1.4.3-GgKPfmYk1rq2rp9ut0wxbG
depends:
    base-4.16.4.0 stm-2.5.0.2 time-1.11.1.1
    time-units-1.0.0-5ANWMnlmGbA6CL2adJPINT

haddock-interfaces:   /usr/share/doc/haskell-rate-limit/html/rate-limit.haddock
haddock-html:         /usr/share/doc/haskell-rate-limit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rate-limit-1.4.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rate-limit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rate-limit
version:              1.4.3
visibility:           public
id:                   rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
key:                  rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/rate-limit
synopsis:             A basic library for rate-limiting IO actions.
description:
    In many cases, it is useful, necessary, or simply nice to limit how
    frequently you perform some action. For example, you may want to limit
    how often your program makes a request of some web site. This library
    is intended as a general-purpose mechanism for rate-limiting IO actions.

category:             Control
abi:                  8fc5760e76bcea34dd4f9b58e04695e1
exposed:              True
exposed-modules:      Control.RateLimit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rate-limit-1.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rate-limit-1.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rate-limit-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rate-limit
hs-libraries:         HSrate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
depends:
    base-4.17.2.1 stm-2.5.1.0 time-1.12.2
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at

haddock-interfaces:   /usr/share/doc/haskell-rate-limit/html/rate-limit.haddock
haddock-html:         /usr/share/doc/haskell-rate-limit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
